/*******************************************************************************
* File Name: .h
* Version 1.10
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component in I2C mode.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_EZI2C_1_H)
#define CY_SCB_PVT_EZI2C_1_H

#include "EZI2C_1.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define EZI2C_1_SetI2CExtClkInterruptMode(interruptMask) EZI2C_1_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define EZI2C_1_ClearI2CExtClkInterruptSource(interruptMask) EZI2C_1_CLEAR_INTR_I2C_EC(interruptMask)
#define EZI2C_1_GetI2CExtClkInterruptSource()                (EZI2C_1_INTR_I2C_EC_REG)
#define EZI2C_1_GetI2CExtClkInterruptMode()                  (EZI2C_1_INTR_I2C_EC_MASK_REG)
#define EZI2C_1_GetI2CExtClkInterruptSourceMasked()          (EZI2C_1_INTR_I2C_EC_MASKED_REG)

/* APIs to service INTR_SPI_EC register */
#define EZI2C_1_SetSpiExtClkInterruptMode(interruptMask) EZI2C_1_WRITE_INTR_SPI_EC_MASK(interruptMask)
#define EZI2C_1_ClearSpiExtClkInterruptSource(interruptMask) EZI2C_1_CLEAR_INTR_SPI_EC(interruptMask)
#define EZI2C_1_GetExtSpiClkInterruptSource()                 (EZI2C_1_INTR_SPI_EC_REG)
#define EZI2C_1_GetExtSpiClkInterruptMode()                   (EZI2C_1_INTR_SPI_EC_MASK_REG)
#define EZI2C_1_GetExtSpiClkInterruptSourceMasked()           (EZI2C_1_INTR_SPI_EC_MASKED_REG)

#if(EZI2C_1_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void EZI2C_1_SetPins(uint32 mode, uint32 subMode, uint32 uartTxRx);
#endif /* (EZI2C_1_SCB_MODE_UNCONFIG_CONST_CFG) */

void EZI2C_1_DisableTxPinsInputBuffer(void);
void EZI2C_1_EnableTxPinsInputBuffer(void);


/**********************************
*     Vars with External Linkage
**********************************/

extern cyisraddress EZI2C_1_customIntrHandler;
extern EZI2C_1_BACKUP_STRUCT EZI2C_1_backup;

#if(EZI2C_1_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common config vars */
    extern uint8 EZI2C_1_scbMode;
    extern uint8 EZI2C_1_scbEnableWake;
    extern uint8 EZI2C_1_scbEnableIntr;

    /* I2C config vars */
    extern uint8 EZI2C_1_mode;
    extern uint8 EZI2C_1_acceptAddr;

    /* SPI/UART config vars */
    extern volatile uint8 * EZI2C_1_rxBuffer;
    extern uint8   EZI2C_1_rxDataBits;
    extern uint32  EZI2C_1_rxBufferSize;

    extern volatile uint8 * EZI2C_1_txBuffer;
    extern uint8   EZI2C_1_txDataBits;
    extern uint32  EZI2C_1_txBufferSize;

    /* EZI2C config vars */
    extern uint8 EZI2C_1_numberOfAddr;
    extern uint8 EZI2C_1_subAddrSize;
#endif /* (EZI2C_1_SCB_MODE_UNCONFIG_CONST_CFG) */

#endif /* (CY_SCB_PVT_EZI2C_1_H) */


/* [] END OF FILE */
